@@ -61,6 +61,10 @@ class DbusManager(dbus.service.Object):
     def hide_from_remote(self):
         self.guake.hide_from_remote()
 
+    @dbus.service.method(DBUS_NAME, out_signature="i")
+    def get_visibility(self):
+        return self.guake.get_visibility()
+
     @dbus.service.method(DBUS_NAME)
     def fullscreen(self):
         self.guake.fullscreen()
@@ -151,6 +155,7 @@ class DbusManager(dbus.service.Object):
 
     @dbus.service.method(DBUS_NAME, in_signature="s")
     def execute_command(self, command):
+        self.guake.add_tab()
         self.guake.execute_command(command)
 
     @dbus.service.method(DBUS_NAME, in_signature="i", out_signature="s")
@@ -189,10 +194,6 @@ class DbusManager(dbus.service.Object):
     def get_selected_uuidtab(self):
         return self.guake.get_selected_uuidtab()
 
-    @dbus.service.method(DBUS_NAME, in_signature="ss")
-    def execute_command_by_uuid(self, tab_uuid, command):
-        self.guake.execute_command_by_uuid(tab_uuid, command)
-
     @dbus.service.method(DBUS_NAME)
     def v_split_current_terminal(self):
         self.guake.get_notebook().get_current_terminal().get_parent().split_v()
@@ -201,6 +202,6 @@ class DbusManager(dbus.service.Object):
     def h_split_current_terminal(self):
         self.guake.get_notebook().get_current_terminal().get_parent().split_h()
 
-    @dbus.service.method(DBUS_NAME, in_signature="s")
-    def execute_command_current_termbox(self, command):
-        self.guake.get_notebook().get_current_terminal().execute_command(command)
+    @dbus.service.method(DBUS_NAME, in_signature="s", out_signature="i")
+    def get_index_from_uuid(self, tab_uuid):
+        return self.guake.get_index_from_uuid(tab_uuid)
