@@ -41,8 +41,13 @@ from optparse import OptionParser
 
 log = logging.getLogger(__name__)
 
-# Force use X11 backend under wayland before any import of GDK through dependencies
+# Force use X11 backend under wayland before any import of GDK through dependencies.
+# This could fix weird problems under Wayland.
+# But if user set the environment variable GUAKE_ENABLE_WAYLAND, then force
+# use Wayland backend.
 os.environ["GDK_BACKEND"] = "x11"
+if "GUAKE_ENABLE_WAYLAND" in os.environ:
+    os.environ["GDK_BACKEND"] = "wayland"
 
 from guake.globals import NAME
 from guake.globals import bindtextdomain
@@ -70,6 +75,7 @@ def main():
     """
     # Force to xterm-256 colors for compatibility with some old command line programs
     os.environ["TERM"] = "xterm-256color"
+    os.environ["TERM_PROGRAM"] = "guake"
 
     # do not use version keywords here, pbr might be slow to find the version of Guake module
     parser = OptionParser()
@@ -117,6 +123,14 @@ def main():
         help=_("Toggles the visibility of the terminal window"),
     )
 
+    parser.add_option(
+        "--is-visible",
+        dest="is_visible",
+        action="store_true",
+        default=False,
+        help=_("Return 1 if Guake is visible, 0 otherwise"),
+    )
+
     parser.add_option(
         "--show",
         dest="show",
@@ -178,6 +192,15 @@ def main():
         help=_("Return the selected tab index."),
     )
 
+    parser.add_option(
+        "-x",
+        "--uuid-index",
+        dest="uuid_index",
+        action="store",
+        default="",
+        help=_("Return the index of the tab with the given terminal UUID, -1 if not found"),
+    )
+
     parser.add_option(
         "-l",
         "--selected-tablabel",
@@ -230,7 +253,7 @@ def main():
         dest="command",
         action="store",
         default="",
-        help=_("Execute an arbitrary command in the selected tab."),
+        help=_("Execute an arbitrary command in a new tab."),
     )
 
     parser.add_option(
@@ -403,7 +426,6 @@ def main():
             "        python3 \\\n"
             "        python3-dbus \\\n"
             "        python3-gi \\\n"
-            "        python3-pbr \\\n"
             "        python3-pip"
         )
         sys.exit(1)
@@ -482,6 +504,11 @@ def main():
     if options.hide:
         remote_object.hide_from_remote()
 
+    if options.is_visible:
+        visibility = remote_object.get_visibility()
+        sys.stdout.write(f"{visibility}\n")
+        only_show_hide = options.show
+
     if options.show_preferences:
         remote_object.show_prefs()
         only_show_hide = options.show
@@ -509,6 +536,11 @@ def main():
         sys.stdout.write(f"{selectedlabel}\n")
         only_show_hide = options.show
 
+    if options.uuid_index:
+        selectedIndex = remote_object.get_index_from_uuid(options.uuid_index)
+        sys.stdout.write(f"{selectedIndex}\n")
+        only_show_hide = options.show
+
     if options.split_vertical:
         remote_object.v_split_current_terminal()
         only_show_hide = options.show
@@ -595,15 +627,15 @@ def main():
             startup_script = instance.settings.general.get_string("startup-script")
             if startup_script:
                 log.info("Calling startup script: %s", startup_script)
-                with subprocess.Popen(
+                pid = subprocess.Popen(  # pylint: disable=consider-using-with
                     [startup_script],
-                    shell=True,
+                    shell=False,
                     stdin=None,
                     stdout=None,
                     stderr=None,
                     close_fds=True,
-                ) as pid:
-                    log.info("Startup script started with pid: %s", pid)
+                )
+                log.info("Startup script started with pid: %s", pid)
                 # Please ensure this is the last line !!!!
     else:
         log.info("--no-startup-script argument defined, so don't execute the startup script")
